@@ -5,26 +5,26 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/git-town/git-town/v13/src/cli/dialog/components"
-	"github.com/git-town/git-town/v13/src/cli/flags"
-	"github.com/git-town/git-town/v13/src/cli/print"
-	"github.com/git-town/git-town/v13/src/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v13/src/config/configdomain"
-	"github.com/git-town/git-town/v13/src/config/gitconfig"
-	"github.com/git-town/git-town/v13/src/execute"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/src/gohacks/slice"
-	"github.com/git-town/git-town/v13/src/gohacks/stringslice"
-	"github.com/git-town/git-town/v13/src/hosting"
-	"github.com/git-town/git-town/v13/src/hosting/hostingdomain"
-	"github.com/git-town/git-town/v13/src/messages"
-	"github.com/git-town/git-town/v13/src/sync"
-	"github.com/git-town/git-town/v13/src/undo/undoconfig"
-	"github.com/git-town/git-town/v13/src/validate"
-	fullInterpreter "github.com/git-town/git-town/v13/src/vm/interpreter/full"
-	"github.com/git-town/git-town/v13/src/vm/opcodes"
-	"github.com/git-town/git-town/v13/src/vm/program"
-	"github.com/git-town/git-town/v13/src/vm/runstate"
+	"github.com/git-town/git-town/v14/src/cli/dialog/components"
+	"github.com/git-town/git-town/v14/src/cli/flags"
+	"github.com/git-town/git-town/v14/src/cli/print"
+	"github.com/git-town/git-town/v14/src/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v14/src/config/configdomain"
+	"github.com/git-town/git-town/v14/src/config/gitconfig"
+	"github.com/git-town/git-town/v14/src/execute"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/gohacks/slice"
+	"github.com/git-town/git-town/v14/src/gohacks/stringslice"
+	"github.com/git-town/git-town/v14/src/hosting"
+	"github.com/git-town/git-town/v14/src/hosting/hostingdomain"
+	"github.com/git-town/git-town/v14/src/messages"
+	"github.com/git-town/git-town/v14/src/sync"
+	"github.com/git-town/git-town/v14/src/undo/undoconfig"
+	"github.com/git-town/git-town/v14/src/validate"
+	fullInterpreter "github.com/git-town/git-town/v14/src/vm/interpreter/full"
+	"github.com/git-town/git-town/v14/src/vm/opcodes"
+	"github.com/git-town/git-town/v14/src/vm/program"
+	"github.com/git-town/git-town/v14/src/vm/runstate"
 	"github.com/spf13/cobra"
 )
 
@@ -54,7 +54,7 @@ If your origin server deletes shipped branches, for example GitHub's feature to
 
 func shipCmd() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
-	addMessageFlag, readMessageFlag := flags.CommitMessage("message", "m", "", "Specify the commit message for the squash commit")
+	addMessageFlag, readMessageFlag := flags.CommitMessage("Specify the commit message for the squash commit")
 	addDryRunFlag, readDryRunFlag := flags.DryRun()
 	cmd := cobra.Command{
 		Use:     "ship",
@@ -146,12 +146,17 @@ type shipConfig struct {
 
 func determineShipConfig(args []string, repo *execute.OpenRepoResult, dryRun, verbose bool) (*shipConfig, gitdomain.BranchesSnapshot, gitdomain.StashSize, bool, error) {
 	dialogTestInputs := components.LoadTestInputs(os.Environ())
-	branchesSnapshot, stashSize, repoStatus, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
+	repoStatus, err := repo.Runner.Backend.RepoStatus()
+	if err != nil {
+		return nil, gitdomain.EmptyBranchesSnapshot(), 0, false, err
+	}
+	branchesSnapshot, stashSize, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
 		DialogTestInputs:      dialogTestInputs,
 		Fetch:                 true,
 		FullConfig:            &repo.Runner.Config.FullConfig,
 		HandleUnfinishedState: true,
 		Repo:                  repo,
+		RepoStatus:            repoStatus,
 		ValidateIsConfigured:  true,
 		ValidateNoOpenChanges: len(args) == 0,
 		Verbose:               verbose,
