@@ -3,8 +3,8 @@ package configdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v13/src/config/configdomain"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/config/configdomain"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
 	"github.com/shoenig/test/must"
 )
 
@@ -19,27 +19,60 @@ func TestLineage(t *testing.T) {
 		t.Parallel()
 		t.Run("provides all ancestor branches, oldest first", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[three] = two
-			lineage[two] = one
-			lineage[one] = main
+			lineage := configdomain.Lineage{
+				three: two,
+				two:   one,
+				one:   main,
+			}
 			have := lineage.Ancestors(three)
 			want := gitdomain.LocalBranchNames{main, one, two}
 			must.Eq(t, want, have)
 		})
 		t.Run("one ancestor", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[one] = main
+			lineage := configdomain.Lineage{
+				one: main,
+			}
 			have := lineage.Ancestors(one)
 			want := gitdomain.LocalBranchNames{main}
 			must.Eq(t, want, have)
 		})
 		t.Run("no ancestors", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.Lineage{
+				one: main,
+			}
+			have := lineage.Ancestors(two)
+			want := gitdomain.LocalBranchNames{}
+			must.Eq(t, want, have)
+		})
+	})
+
+	t.Run("AncestorsWithoutRoot", func(t *testing.T) {
+		t.Parallel()
+		t.Run("provides all ancestor branches, oldest first", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.Lineage{}
+			lineage[three] = two
+			lineage[two] = one
+			lineage[one] = main
+			have := lineage.AncestorsWithoutRoot(three)
+			want := gitdomain.LocalBranchNames{one, two}
+			must.Eq(t, want, have)
+		})
+		t.Run("one ancestor", func(t *testing.T) {
 			t.Parallel()
 			lineage := configdomain.Lineage{}
 			lineage[one] = main
-			have := lineage.Ancestors(two)
+			have := lineage.AncestorsWithoutRoot(one)
+			want := gitdomain.LocalBranchNames{}
+			must.Eq(t, want, have)
+		})
+		t.Run("no ancestors", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.Lineage{}
+			lineage[one] = main
+			have := lineage.AncestorsWithoutRoot(two)
 			want := gitdomain.LocalBranchNames{}
 			must.Eq(t, want, have)
 		})
@@ -47,8 +80,9 @@ func TestLineage(t *testing.T) {
 
 	t.Run("BranchAndAncestors", func(t *testing.T) {
 		t.Parallel()
-		lineage := configdomain.Lineage{}
-		lineage[one] = main
+		lineage := configdomain.Lineage{
+			one: main,
+		}
 		have := lineage.BranchAndAncestors(one)
 		want := gitdomain.LocalBranchNames{main, one}
 		must.Eq(t, want, have)
@@ -58,10 +92,11 @@ func TestLineage(t *testing.T) {
 		t.Parallel()
 		t.Run("deep lineage, multiple branches", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[one] = main
-			lineage[two] = one
-			lineage[three] = two
+			lineage := configdomain.Lineage{
+				one:   main,
+				two:   one,
+				three: two,
+			}
 			give := gitdomain.LocalBranchNames{two, one}
 			have := lineage.BranchesAndAncestors(give)
 			want := gitdomain.LocalBranchNames{main, one, two}
@@ -69,10 +104,11 @@ func TestLineage(t *testing.T) {
 		})
 		t.Run("deep lineage, multiple branches out of order", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[one] = main
-			lineage[two] = one
-			lineage[three] = two
+			lineage := configdomain.Lineage{
+				one:   main,
+				two:   one,
+				three: two,
+			}
 			give := gitdomain.LocalBranchNames{one, two, main, three}
 			have := lineage.BranchesAndAncestors(give)
 			want := gitdomain.LocalBranchNames{main, one, two, three}
@@ -80,10 +116,11 @@ func TestLineage(t *testing.T) {
 		})
 		t.Run("deep lineage, single branch", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[one] = main
-			lineage[two] = one
-			lineage[three] = two
+			lineage := configdomain.Lineage{
+				one:   main,
+				two:   one,
+				three: two,
+			}
 			give := gitdomain.LocalBranchNames{three}
 			have := lineage.BranchesAndAncestors(give)
 			want := gitdomain.LocalBranchNames{main, one, two, three}
@@ -93,19 +130,64 @@ func TestLineage(t *testing.T) {
 
 	t.Run("BranchAndAncestors", func(t *testing.T) {
 		t.Parallel()
-		lineage := configdomain.Lineage{}
-		lineage[one] = main
+		lineage := configdomain.Lineage{
+			one: main,
+		}
 		have := lineage.BranchAndAncestors(one)
 		want := gitdomain.LocalBranchNames{main, one}
 		must.Eq(t, want, have)
 	})
 
+	t.Run("BranchLineageWithoutRoot", func(t *testing.T) {
+		t.Parallel()
+		t.Run("only root exists", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.Lineage{}
+			have := lineage.BranchLineageWithoutRoot(main)
+			want := gitdomain.LocalBranchNames{}
+			must.Eq(t, want, have)
+		})
+		t.Run("one branch and root exist", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.Lineage{
+				one: main,
+			}
+			have := lineage.BranchLineageWithoutRoot(one)
+			want := gitdomain.LocalBranchNames{one}
+			must.Eq(t, want, have)
+		})
+		t.Run("multiple branches", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.Lineage{
+				one: main,
+				two: one,
+			}
+			want := gitdomain.LocalBranchNames{one, two}
+			t.Run("given root", func(t *testing.T) {
+				t.Parallel()
+				have := lineage.BranchLineageWithoutRoot(main)
+				must.Eq(t, want, have)
+			})
+			t.Run("given middle branch", func(t *testing.T) {
+				t.Parallel()
+				have := lineage.BranchLineageWithoutRoot(one)
+				must.Eq(t, want, have)
+			})
+			t.Run("given leaf branch", func(t *testing.T) {
+				t.Parallel()
+				have := lineage.BranchLineageWithoutRoot(two)
+				must.Eq(t, want, have)
+			})
+		})
+	})
+
 	t.Run("BranchNames", func(t *testing.T) {
 		t.Parallel()
-		lineage := configdomain.Lineage{}
-		lineage[one] = main
-		lineage[two] = main
-		lineage[three] = main
+		lineage := configdomain.Lineage{
+			one:   main,
+			two:   main,
+			three: main,
+		}
 		have := lineage.BranchNames()
 		want := gitdomain.LocalBranchNames{one, three, two}
 		must.Eq(t, want, have)
@@ -117,18 +199,20 @@ func TestLineage(t *testing.T) {
 			t.Parallel()
 			twoA := gitdomain.NewLocalBranchName("twoA")
 			twoB := gitdomain.NewLocalBranchName("twoB")
-			lineage := configdomain.Lineage{}
-			lineage[twoA] = one
-			lineage[twoB] = one
+			lineage := configdomain.Lineage{
+				twoA: one,
+				twoB: one,
+			}
 			have := lineage.Children(one)
 			want := gitdomain.LocalBranchNames{twoA, twoB}
 			must.Eq(t, want, have)
 		})
 		t.Run("provides only the immediate children, i.e. no grandchildren", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[two] = one
-			lineage[three] = two
+			lineage := configdomain.Lineage{
+				two:   one,
+				three: two,
+			}
 			have := lineage.Children(one)
 			want := gitdomain.LocalBranchNames{two}
 			must.Eq(t, want, have)
@@ -146,8 +230,9 @@ func TestLineage(t *testing.T) {
 		t.Parallel()
 		t.Run("has a parent", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[two] = one
+			lineage := configdomain.Lineage{
+				two: one,
+			}
 			must.True(t, lineage.HasParents(two))
 		})
 		t.Run("has no parent", func(t *testing.T) {
@@ -157,27 +242,86 @@ func TestLineage(t *testing.T) {
 		})
 	})
 
+	t.Run("Descendants", func(t *testing.T) {
+		t.Parallel()
+		t.Run("branch has no children", func(t *testing.T) {
+			t.Parallel()
+			branch := gitdomain.NewLocalBranchName("branch")
+			other := gitdomain.NewLocalBranchName("other")
+			lineage := configdomain.Lineage{
+				branch: main,
+				other:  main,
+			}
+			have := lineage.Descendants(branch)
+			want := gitdomain.LocalBranchNames{}
+			must.Eq(t, want, have)
+		})
+		t.Run("branch has only direct children", func(t *testing.T) {
+			t.Parallel()
+			branch := gitdomain.NewLocalBranchName("branch")
+			child1 := gitdomain.NewLocalBranchName("child1")
+			child2 := gitdomain.NewLocalBranchName("child2")
+			other := gitdomain.NewLocalBranchName("other")
+			lineage := configdomain.Lineage{
+				branch: main,
+				child1: branch,
+				child2: branch,
+				other:  main,
+			}
+			have := lineage.Descendants(branch)
+			want := gitdomain.LocalBranchNames{child1, child2}
+			must.Eq(t, want, have)
+		})
+		t.Run("branch has grandchildren", func(t *testing.T) {
+			t.Parallel()
+			branch := gitdomain.NewLocalBranchName("branch")
+			child1 := gitdomain.NewLocalBranchName("child1")
+			child1a := gitdomain.NewLocalBranchName("child1a")
+			child1b := gitdomain.NewLocalBranchName("child1b")
+			child2 := gitdomain.NewLocalBranchName("child2")
+			child2a := gitdomain.NewLocalBranchName("child2a")
+			child2b := gitdomain.NewLocalBranchName("child2b")
+			other := gitdomain.NewLocalBranchName("other")
+			lineage := configdomain.Lineage{
+				branch:  main,
+				child1:  branch,
+				child1a: child1,
+				child1b: child1,
+				child2:  branch,
+				child2a: child2,
+				child2b: child2,
+				other:   main,
+			}
+			have := lineage.Descendants(branch)
+			want := gitdomain.LocalBranchNames{child1, child1a, child1b, child2, child2a, child2b}
+			must.Eq(t, want, have)
+		})
+	})
+
 	t.Run("IsAncestor", func(t *testing.T) {
 		t.Run("recognizes greatgrandparent", func(t *testing.T) {
 			t.Parallel()
 			four := gitdomain.NewLocalBranchName("four")
-			lineage := configdomain.Lineage{}
-			lineage[four] = three
-			lineage[three] = two
-			lineage[two] = one
+			lineage := configdomain.Lineage{
+				four:  three,
+				three: two,
+				two:   one,
+			}
 			must.True(t, lineage.IsAncestor(one, four))
 		})
 		t.Run("child branches are not ancestors", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[two] = one
+			lineage := configdomain.Lineage{
+				two: one,
+			}
 			must.True(t, lineage.IsAncestor(one, two))
 		})
 		t.Run("unrelated branches are not ancestors", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[two] = one
-			lineage[three] = one
+			lineage := configdomain.Lineage{
+				two:   one,
+				three: one,
+			}
 			must.False(t, lineage.IsAncestor(two, three))
 		})
 	})
@@ -189,13 +333,14 @@ func TestLineage(t *testing.T) {
 			oneA1 := gitdomain.NewLocalBranchName("oneA1")
 			oneA2 := gitdomain.NewLocalBranchName("oneA2")
 			oneB := gitdomain.NewLocalBranchName("oneB")
-			lineage := configdomain.Lineage{}
-			lineage[one] = main
-			lineage[oneA] = one
-			lineage[oneB] = one
-			lineage[oneA1] = oneA
-			lineage[oneA2] = oneA
-			lineage[two] = main
+			lineage := configdomain.Lineage{
+				one:   main,
+				oneA:  one,
+				oneB:  one,
+				oneA1: oneA,
+				oneA2: oneA,
+				two:   main,
+			}
 			have := lineage.BranchNames()
 			want := gitdomain.LocalBranchNames{one, oneA, oneA1, oneA2, oneB, two}
 			lineage.OrderHierarchically(have)
@@ -207,11 +352,12 @@ func TestLineage(t *testing.T) {
 			two := gitdomain.NewLocalBranchName("two")
 			three := gitdomain.NewLocalBranchName("three")
 			four := gitdomain.NewLocalBranchName("four")
-			lineage := configdomain.Lineage{}
-			lineage[one] = main
-			lineage[two] = one
-			lineage[three] = two
-			lineage[four] = three
+			lineage := configdomain.Lineage{
+				one:   main,
+				two:   one,
+				three: two,
+				four:  three,
+			}
 			have := gitdomain.LocalBranchNames{four, one}
 			want := gitdomain.LocalBranchNames{one, four}
 			lineage.OrderHierarchically(have)
@@ -222,10 +368,11 @@ func TestLineage(t *testing.T) {
 			one := gitdomain.NewLocalBranchName("one")
 			two := gitdomain.NewLocalBranchName("two")
 			three := gitdomain.NewLocalBranchName("three")
-			lineage := configdomain.Lineage{}
-			lineage[one] = main
-			lineage[two] = one
-			lineage[three] = two
+			lineage := configdomain.Lineage{
+				one:   main,
+				two:   one,
+				three: two,
+			}
 			have := gitdomain.LocalBranchNames{one, two, main, three}
 			want := gitdomain.LocalBranchNames{main, one, two, three}
 			lineage.OrderHierarchically(have)
@@ -300,19 +447,21 @@ func TestLineage(t *testing.T) {
 			prod := gitdomain.NewLocalBranchName("prod")
 			hotfix1 := gitdomain.NewLocalBranchName("hotfix1")
 			hotfix2 := gitdomain.NewLocalBranchName("hotfix2")
-			lineage := configdomain.Lineage{}
-			lineage[two] = one
-			lineage[one] = main
-			lineage[hotfix1] = prod
-			lineage[hotfix2] = prod
+			lineage := configdomain.Lineage{
+				two:     one,
+				one:     main,
+				hotfix1: prod,
+				hotfix2: prod,
+			}
 			have := lineage.Roots()
 			want := gitdomain.LocalBranchNames{main, prod}
 			must.Eq(t, want, have)
 		})
 		t.Run("no stacked changes", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			lineage[one] = main
+			lineage := configdomain.Lineage{
+				one: main,
+			}
 			have := lineage.Roots()
 			want := gitdomain.LocalBranchNames{main}
 			must.Eq(t, want, have)
