@@ -5,8 +5,8 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/git-town/git-town/v13/src/config/configdomain"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/config/configdomain"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
 )
 
 // Key contains all the keys used in Git Town's Git metadata configuration.
@@ -29,6 +29,7 @@ func (self *Key) UnmarshalJSON(b []byte) error {
 
 const (
 	KeyAliasAppend                         = Key("alias.append")
+	KeyAliasCompress                       = Key("alias.compress")
 	KeyAliasContribute                     = Key("alias.contribute")
 	KeyAliasDiffParent                     = Key("alias.diff-parent")
 	KeyAliasHack                           = Key("alias.hack")
@@ -124,6 +125,8 @@ func KeyForAliasableCommand(aliasableCommand configdomain.AliasableCommand) Key
 	switch aliasableCommand {
 	case configdomain.AliasableCommandAppend:
 		return KeyAliasAppend
+	case configdomain.AliasableCommandCompress:
+		return KeyAliasCompress
 	case configdomain.AliasableCommandContribute:
 		return KeyAliasContribute
 	case configdomain.AliasableCommandDiffParent:
