@@ -4,10 +4,10 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/git-town/git-town/v13/src/config/configdomain"
-	"github.com/git-town/git-town/v13/src/config/gitconfig"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/src/messages"
+	"github.com/git-town/git-town/v14/src/config/configdomain"
+	"github.com/git-town/git-town/v14/src/config/gitconfig"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/messages"
 )
 
 type FrontendRunner interface {
@@ -75,6 +75,24 @@ func (self *FrontendCommands) ContinueRebase() error {
 	return self.Runner.Run("git", "rebase", "--continue")
 }
 
+// CreateAndCheckoutBranch creates a new branch with the given name and checks it out using a single Git operation.
+// The created branch is a normal branch.
+// To create feature branches, use CreateFeatureBranch.
+func (self *FrontendCommands) CreateAndCheckoutBranch(name gitdomain.LocalBranchName) error {
+	err := self.Runner.Run("git", "checkout", "-b", name.String())
+	self.SetCachedCurrentBranch(name)
+	return err
+}
+
+// CreateAndCheckoutBranchWithParent creates a new branch with the given name and parent and checks it out using a single Git operation.
+// The created branch is a normal branch.
+// To create feature branches, use CreateFeatureBranch.
+func (self *FrontendCommands) CreateAndCheckoutBranchWithParent(name gitdomain.LocalBranchName, parent gitdomain.Location) error {
+	err := self.Runner.Run("git", "checkout", "-b", name.String(), parent.String())
+	self.SetCachedCurrentBranch(name)
+	return err
+}
+
 // CreateBranch creates a new branch with the given name.
 // The created branch is a normal branch.
 // To create feature branches, use CreateFeatureBranch.
@@ -88,7 +106,7 @@ func (self *FrontendCommands) CreateRemoteBranch(localSHA gitdomain.SHA, branch
 	if noPushHook {
 		args = append(args, "--no-verify")
 	}
-	args = append(args, gitdomain.OriginRemote.String(), localSHA.String()+":refs/heads/"+branch.String())
+	args = append(args, gitdomain.RemoteOrigin.String(), localSHA.String()+":refs/heads/"+branch.String())
 	return self.Runner.Run("git", args...)
 }
 
@@ -146,7 +164,7 @@ func (self *FrontendCommands) Fetch() error {
 
 // FetchUpstream fetches updates from the upstream remote.
 func (self *FrontendCommands) FetchUpstream(branch gitdomain.LocalBranchName) error {
-	return self.Runner.Run("git", "fetch", gitdomain.UpstreamRemote.String(), branch.String())
+	return self.Runner.Run("git", "fetch", gitdomain.RemoteUpstream.String(), branch.String())
 }
 
 // PushBranch pushes the branch with the given name to origin.
@@ -221,7 +239,7 @@ func (self *FrontendCommands) ResetCurrentBranchToSHA(sha gitdomain.SHA, hard bo
 
 // ResetRemoteBranchToSHA sets the given remote branch to the given SHA.
 func (self *FrontendCommands) ResetRemoteBranchToSHA(branch gitdomain.RemoteBranchName, sha gitdomain.SHA) error {
-	return self.Runner.Run("git", "push", "--force-with-lease", gitdomain.OriginRemote.String(), sha.String()+":"+branch.LocalBranchName().String())
+	return self.Runner.Run("git", "push", "--force-with-lease", gitdomain.RemoteOrigin.String(), sha.String()+":"+branch.LocalBranchName().String())
 }
 
 // RevertCommit reverts the commit with the given SHA.
