@@ -4,8 +4,8 @@ import (
 	"encoding/json"
 	"testing"
 
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/test/asserts"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/test/asserts"
 	"github.com/shoenig/test/must"
 )
 
@@ -72,7 +72,7 @@ func TestRemoteBranchName(t *testing.T) {
 		t.Parallel()
 		remoteBranch := gitdomain.NewRemoteBranchName("origin/branch")
 		remote, localBranch := remoteBranch.Parts()
-		must.EqOp(t, gitdomain.OriginRemote, remote)
+		must.EqOp(t, gitdomain.RemoteOrigin, remote)
 		must.EqOp(t, gitdomain.NewLocalBranchName("branch"), localBranch)
 	})
 
