@@ -26,6 +26,13 @@ const (
 	CodeHosting                        = "Code hosting: %s\n"
 	CommandsRun                        = "Ran %d shell commands."
 	CommitMessageProblem               = "cannot determine last commit message: %w"
+	CompressUnsynced                   = "please sync branch %q before compressing it"
+	CompressIsPerennial                = "better not compress perennial branches"
+	CompressAlreadyOneCommit           = "branch %q has already just one commit"
+	CompressContributionBranch         = "you are merely contributing to branch %q and should leave compressing it to the branch owner"
+	CompressNoCommits                  = "branch %q has no commits"
+	CompressObservedBranch             = "you are merely observing branch %q and should leave compressing it to the branch owner"
+	CompressParkedBranch               = "branch %q and should not compress it"
 	CompletionTypeUnknown              = "unknown completion type: %q"
 	ConfigFileCannotRead               = "cannot read the configuration file %q: %w"
 	ConfigFileInvalidData              = "the configuration file %q does not contain TOML-formatted content: %w"
