@@ -1,14 +1,14 @@
 package config
 
 import (
-	"github.com/git-town/git-town/v13/src/cli/print"
-	"github.com/git-town/git-town/v13/src/config/gitconfig"
-	"github.com/git-town/git-town/v13/src/git"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/src/undo/undoconfig"
-	"github.com/git-town/git-town/v13/src/vm/program"
-	"github.com/git-town/git-town/v13/src/vm/runstate"
-	"github.com/git-town/git-town/v13/src/vm/statefile"
+	"github.com/git-town/git-town/v14/src/cli/print"
+	"github.com/git-town/git-town/v14/src/config/gitconfig"
+	"github.com/git-town/git-town/v14/src/git"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/undo/undoconfig"
+	"github.com/git-town/git-town/v14/src/vm/program"
+	"github.com/git-town/git-town/v14/src/vm/runstate"
+	"github.com/git-town/git-town/v14/src/vm/statefile"
 )
 
 // Finished is called when a Git Town command that only changes configuration has finished successfully.
@@ -16,11 +16,11 @@ func Finished(args FinishedArgs) error {
 	// TODO: extract the code to load a config snapshot into a reusable function
 	//       since it exists in multiple places
 	configGitAccess := gitconfig.Access{Runner: args.Runner.Backend.Runner}
-	globalSnapshot, _, err := configGitAccess.LoadGlobal()
+	globalSnapshot, _, err := configGitAccess.LoadGlobal(false)
 	if err != nil {
 		return err
 	}
-	localSnapshot, _, err := configGitAccess.LoadLocal()
+	localSnapshot, _, err := configGitAccess.LoadLocal(false)
 	if err != nil {
 		return err
 	}
