@@ -4,12 +4,12 @@ import (
 	"errors"
 	"fmt"
 
-	"github.com/git-town/git-town/v13/src/cli/print"
-	"github.com/git-town/git-town/v13/src/config/gitconfig"
-	"github.com/git-town/git-town/v13/src/messages"
-	"github.com/git-town/git-town/v13/src/undo/undoconfig"
-	"github.com/git-town/git-town/v13/src/vm/shared"
-	"github.com/git-town/git-town/v13/src/vm/statefile"
+	"github.com/git-town/git-town/v14/src/cli/print"
+	"github.com/git-town/git-town/v14/src/config/gitconfig"
+	"github.com/git-town/git-town/v14/src/messages"
+	"github.com/git-town/git-town/v14/src/undo/undoconfig"
+	"github.com/git-town/git-town/v14/src/vm/shared"
+	"github.com/git-town/git-town/v14/src/vm/statefile"
 )
 
 // errored is called when the given opcode has resulted in the given error.
@@ -20,11 +20,11 @@ func errored(failedOpcode shared.Opcode, runErr error, args ExecuteArgs) error {
 		return err
 	}
 	configGitAccess := gitconfig.Access{Runner: args.Run.Backend.Runner}
-	globalSnapshot, _, err := configGitAccess.LoadGlobal()
+	globalSnapshot, _, err := configGitAccess.LoadGlobal(false)
 	if err != nil {
 		return err
 	}
-	localSnapshot, _, err := configGitAccess.LoadLocal()
+	localSnapshot, _, err := configGitAccess.LoadLocal(false)
 	if err != nil {
 		return err
 	}
