@@ -3,11 +3,11 @@ package interpreter
 import (
 	"fmt"
 
-	"github.com/git-town/git-town/v13/src/cli/print"
-	"github.com/git-town/git-town/v13/src/config/gitconfig"
-	"github.com/git-town/git-town/v13/src/messages"
-	"github.com/git-town/git-town/v13/src/undo/undoconfig"
-	"github.com/git-town/git-town/v13/src/vm/statefile"
+	"github.com/git-town/git-town/v14/src/cli/print"
+	"github.com/git-town/git-town/v14/src/config/gitconfig"
+	"github.com/git-town/git-town/v14/src/messages"
+	"github.com/git-town/git-town/v14/src/undo/undoconfig"
+	"github.com/git-town/git-town/v14/src/vm/statefile"
 )
 
 // finished is called when executing all steps has successfully finished.
@@ -21,11 +21,11 @@ func finished(args ExecuteArgs) error {
 		return err
 	}
 	configGitAccess := gitconfig.Access{Runner: args.Run.Backend.Runner}
-	globalSnapshot, _, err := configGitAccess.LoadGlobal()
+	globalSnapshot, _, err := configGitAccess.LoadGlobal(false)
 	if err != nil {
 		return err
 	}
-	localSnapshot, _, err := configGitAccess.LoadLocal()
+	localSnapshot, _, err := configGitAccess.LoadLocal(false)
 	if err != nil {
 		return err
 	}
