@@ -5,8 +5,8 @@ package opcodes
 import (
 	"errors"
 
-	"github.com/git-town/git-town/v13/src/gohacks"
-	"github.com/git-town/git-town/v13/src/vm/shared"
+	"github.com/git-town/git-town/v14/src/gohacks"
+	"github.com/git-town/git-town/v14/src/vm/shared"
 )
 
 // undeclaredOpcodeMethods can be added to structs in this package to satisfy the shared.Opcode interface even if they don't declare all required methods.
@@ -57,8 +57,8 @@ func Types() []shared.Opcode {
 		&ConnectorMergeProposal{},
 		&ContinueMerge{},
 		&ContinueRebase{},
+		&CreateAndCheckoutBranchExistingParent{},
 		&CreateBranch{},
-		&CreateBranchExistingParent{},
 		&CreateProposal{},
 		&CreateRemoteBranch{},
 		&CreateTrackingBranch{},
