@@ -3,10 +3,9 @@ package opcodes
 import (
 	"fmt"
 
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/src/gohacks/slice"
-	"github.com/git-town/git-town/v13/src/messages"
-	"github.com/git-town/git-town/v13/src/vm/shared"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/messages"
+	"github.com/git-town/git-town/v14/src/vm/shared"
 )
 
 // RevertCommit adds a commit to the current branch
@@ -26,8 +25,8 @@ func (self *RevertCommit) Run(args shared.RunArgs) error {
 	if err != nil {
 		return err
 	}
-	if !slice.Contains(commitsInCurrentBranch, self.SHA) {
-		return fmt.Errorf(messages.BranchDoesntContainCommit, currentBranch, self.SHA, commitsInCurrentBranch.Join("|"))
+	if !commitsInCurrentBranch.ContainsSHA(self.SHA) {
+		return fmt.Errorf(messages.BranchDoesntContainCommit, currentBranch, self.SHA, commitsInCurrentBranch.SHAs().Join("|"))
 	}
 	return args.Runner.Frontend.RevertCommit(self.SHA)
 }
