@@ -6,16 +6,16 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/git-town/git-town/v13/src/config/configdomain"
-	"github.com/git-town/git-town/v13/src/config/gitconfig"
-	prodgit "github.com/git-town/git-town/v13/src/git"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/src/gohacks/slice"
-	"github.com/git-town/git-town/v13/src/gohacks/stringslice"
-	"github.com/git-town/git-town/v13/test/asserts"
-	"github.com/git-town/git-town/v13/test/datatable"
-	"github.com/git-town/git-town/v13/test/git"
-	"github.com/git-town/git-town/v13/test/subshell"
+	"github.com/git-town/git-town/v14/src/config/configdomain"
+	"github.com/git-town/git-town/v14/src/config/gitconfig"
+	prodgit "github.com/git-town/git-town/v14/src/git"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/gohacks/slice"
+	"github.com/git-town/git-town/v14/src/gohacks/stringslice"
+	"github.com/git-town/git-town/v14/test/asserts"
+	"github.com/git-town/git-town/v14/test/datatable"
+	"github.com/git-town/git-town/v14/test/git"
+	"github.com/git-town/git-town/v14/test/subshell"
 )
 
 const ConfigFileCommitMessage = "persisted config file"
@@ -163,6 +163,12 @@ func (self *TestCommands) CreateFile(name, content string) {
 	asserts.NoError(os.WriteFile(filePath, []byte(content), 0o700))
 }
 
+// CreateFolder creates a folder with the given name in this repository.
+func (self *TestCommands) CreateFolder(name string) {
+	folderPath := filepath.Join(self.WorkingDir, name)
+	asserts.NoError(os.MkdirAll(folderPath, os.ModePerm))
+}
+
 // CreateObservedBranches creates perennial branches with the given names in this repository.
 func (self *TestCommands) CreateObservedBranches(names ...gitdomain.LocalBranchName) {
 	main := gitdomain.NewLocalBranchName("main")
@@ -305,12 +311,16 @@ func (self *TestCommands) HasFile(name, content string) string {
 // LineageTable provides the currently configured lineage information as a DataTable.
 func (self *TestCommands) LineageTable() datatable.DataTable {
 	result := datatable.DataTable{}
-	self.Config.Reload()
-	lineage := self.Config.FullConfig.Lineage
 	result.AddRow("BRANCH", "PARENT")
+	_, localGitConfig, _ := self.Config.GitConfig.LoadLocal(false) // we ignore the Git cache here because reloading a config in the middle of a Git Town command doesn't change the cached initial state of the repo
+	if localGitConfig.Lineage == nil {
+		return result
+	}
+	lineage := *localGitConfig.Lineage
 	for _, branchName := range lineage.BranchNames() {
 		result.AddRow(branchName.String(), lineage[branchName].String())
 	}
+	result.Sort()
 	return result
 }
 
