@@ -15,22 +15,21 @@ import (
 	"github.com/acarl005/stripansi"
 	"github.com/cucumber/godog"
 	"github.com/cucumber/messages-go/v10"
-	"github.com/git-town/git-town/v13/src/cli/dialog/components"
-	"github.com/git-town/git-town/v13/src/cli/print"
-	"github.com/git-town/git-town/v13/src/config/configdomain"
-	"github.com/git-town/git-town/v13/src/config/configfile"
-	"github.com/git-town/git-town/v13/src/config/gitconfig"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/src/gohacks"
-	"github.com/git-town/git-town/v13/src/gohacks/slice"
-	"github.com/git-town/git-town/v13/test/asserts"
-	"github.com/git-town/git-town/v13/test/commands"
-	"github.com/git-town/git-town/v13/test/datatable"
-	"github.com/git-town/git-town/v13/test/fixture"
-	"github.com/git-town/git-town/v13/test/git"
-	"github.com/git-town/git-town/v13/test/helpers"
-	"github.com/git-town/git-town/v13/test/output"
-	"github.com/git-town/git-town/v13/test/subshell"
+	"github.com/git-town/git-town/v14/src/cli/dialog/components"
+	"github.com/git-town/git-town/v14/src/cli/print"
+	"github.com/git-town/git-town/v14/src/config/configdomain"
+	"github.com/git-town/git-town/v14/src/config/configfile"
+	"github.com/git-town/git-town/v14/src/config/gitconfig"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/gohacks"
+	"github.com/git-town/git-town/v14/test/asserts"
+	"github.com/git-town/git-town/v14/test/commands"
+	"github.com/git-town/git-town/v14/test/datatable"
+	"github.com/git-town/git-town/v14/test/fixture"
+	"github.com/git-town/git-town/v14/test/git"
+	"github.com/git-town/git-town/v14/test/helpers"
+	"github.com/git-town/git-town/v14/test/output"
+	"github.com/git-town/git-town/v14/test/subshell"
 	"github.com/google/go-cmp/cmp"
 )
 
@@ -86,7 +85,6 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^a branch "([^"]*)"$`, func(branch string) error {
-		state.initialLocalBranches = append(state.initialLocalBranches, gitdomain.NewLocalBranchName(branch))
 		state.fixture.DevRepo.CreateBranch(gitdomain.NewLocalBranchName(branch), gitdomain.NewLocalBranchName("main"))
 		return nil
 	})
@@ -99,16 +97,17 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	suite.Step(`^a feature branch "([^"]+)" as a child of "([^"]+)"$`, func(branchText, parentBranch string) error {
 		branch := gitdomain.NewLocalBranchName(branchText)
 		state.fixture.DevRepo.CreateChildFeatureBranch(branch, gitdomain.NewLocalBranchName(parentBranch))
-		state.initialLocalBranches = append(state.initialLocalBranches, branch)
-		state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
-		state.initialLineage.AddRow(branchText, parentBranch)
-		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
+		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
+		return nil
+	})
+
+	suite.Step(`^a folder "([^"]*)"$`, func(name string) error {
+		state.fixture.DevRepo.CreateFolder(name)
 		return nil
 	})
 
 	suite.Step(`^a known remote feature branch "([^"]*)"$`, func(branchText string) error {
 		branch := gitdomain.NewLocalBranchName(branchText)
-		state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
 		// we are creating a remote branch in the remote repo --> it is a local branch there
 		state.fixture.OriginRepo.CreateBranch(branch, gitdomain.NewLocalBranchName("main"))
 		state.fixture.DevRepo.TestCommands.Fetch()
@@ -126,11 +125,8 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		branch := gitdomain.NewLocalBranchName(branchText)
 		isLocal := localStr != ""
 		state.fixture.DevRepo.CreateFeatureBranch(branch)
-		state.initialLocalBranches = append(state.initialLocalBranches, branch)
-		state.initialLineage.AddRow(branchText, "main")
 		if !isLocal {
-			state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
-			state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
+			state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
 			return nil
 		}
 		return nil
@@ -139,19 +135,14 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	suite.Step(`^a parked branch "([^"]+)"$`, func(branchText string) error {
 		branch := gitdomain.NewLocalBranchName(branchText)
 		state.fixture.DevRepo.CreateParkedBranches(branch)
-		state.initialLocalBranches = append(state.initialLocalBranches, branch)
-		state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
-		state.initialLineage.AddRow(branchText, "main")
-		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
+		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
 		return nil
 	})
 
 	suite.Step(`^a perennial branch "([^"]+)"$`, func(branchText string) error {
 		branch := gitdomain.NewLocalBranchName(branchText)
 		state.fixture.DevRepo.CreatePerennialBranches(branch)
-		state.initialLocalBranches = append(state.initialLocalBranches, branch)
-		state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
-		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
+		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
 		return nil
 	})
 
@@ -166,7 +157,6 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 
 	suite.Step(`^a remote feature branch "([^"]*)"$`, func(branchText string) error {
 		branch := gitdomain.NewLocalBranchName(branchText)
-		state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
 		// we are creating a remote branch in the remote repo --> it is a local branch there
 		state.fixture.OriginRepo.CreateBranch(branch, gitdomain.NewLocalBranchName("main"))
 		return nil
@@ -540,8 +530,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I add this commit to the current branch:$`, func(table *messages.PickleStepArgument_PickleTable) error {
-		commits := git.FromGherkinTable(table)
-		commit := commits[0]
+		commit := git.FromGherkinTable(table)[0]
 		state.fixture.DevRepo.CreateFile(commit.FileName, commit.FileContent)
 		state.fixture.DevRepo.StageFiles(commit.FileName)
 		state.fixture.DevRepo.CommitStagedChanges(commit.Message)
@@ -579,6 +568,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I (?:run|ran) "(.+)"$`, func(command string) error {
+		state.CaptureState()
 		updateInitialSHAs(state)
 		state.runOutput, state.runExitCode = state.fixture.DevRepo.MustQueryStringCode(command)
 		state.fixture.DevRepo.Config.Reload()
@@ -586,6 +576,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I run "([^"]*)" and close the editor$`, func(cmd string) error {
+		state.CaptureState()
 		updateInitialSHAs(state)
 		env := append(os.Environ(), "GIT_EDITOR=true")
 		state.runOutput, state.runExitCode = state.fixture.DevRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Env: env})
@@ -594,6 +585,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I run "([^"]*)" and enter an empty commit message$`, func(cmd string) error {
+		state.CaptureState()
 		updateInitialSHAs(state)
 		state.fixture.DevRepo.MockCommitMessage("")
 		state.runOutput, state.runExitCode = state.fixture.DevRepo.MustQueryStringCode(cmd)
@@ -602,6 +594,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I run "([^"]*)" and enter "([^"]*)" for the commit message$`, func(cmd, message string) error {
+		state.CaptureState()
 		updateInitialSHAs(state)
 		state.fixture.DevRepo.MockCommitMessage(message)
 		state.runOutput, state.runExitCode = state.fixture.DevRepo.MustQueryStringCode(cmd)
@@ -610,6 +603,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I run "([^"]*)" in the other worktree and enter "([^"]*)" for the commit message$`, func(cmd, message string) error {
+		state.CaptureState()
 		updateInitialSHAs(state)
 		state.fixture.SecondWorktree.MockCommitMessage(message)
 		state.runOutput, state.runExitCode = state.fixture.SecondWorktree.MustQueryStringCode(cmd)
@@ -618,6 +612,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I (?:run|ran) "([^"]+)" and enter into the dialogs?:$`, func(cmd string, input *messages.PickleStepArgument_PickleTable) error {
+		state.CaptureState()
 		updateInitialSHAs(state)
 		env := os.Environ()
 		answers, err := helpers.TableToInputEnv(input)
@@ -633,6 +628,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I run "([^"]*)", enter into the dialog, and close the next editor:$`, func(cmd string, input *messages.PickleStepArgument_PickleTable) error {
+		state.CaptureState()
 		updateInitialSHAs(state)
 		env := append(os.Environ(), "GIT_EDITOR=true")
 		answers, err := helpers.TableToInputEnv(input)
@@ -648,6 +644,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I run "([^"]+)" in the "([^"]+)" folder$`, func(cmd, folderName string) error {
+		state.CaptureState()
 		updateInitialSHAs(state)
 		state.runOutput, state.runExitCode = state.fixture.DevRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Dir: folderName})
 		state.fixture.DevRepo.Config.Reload()
@@ -655,6 +652,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^I run "([^"]+)" in the other worktree$`, func(cmd string) error {
+		state.CaptureState()
 		updateInitialSHAs(state)
 		state.runOutput, state.runExitCode = state.fixture.SecondWorktree.MustQueryStringCode(cmd)
 		state.fixture.SecondWorktree.Config.Reload()
@@ -1034,8 +1032,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^my repo does not have an origin$`, func() error {
-		state.fixture.DevRepo.RemoveRemote(gitdomain.OriginRemote)
-		state.initialRemoteBranches = gitdomain.LocalBranchNames{}
+		state.fixture.DevRepo.RemoveRemote(gitdomain.RemoteOrigin)
 		state.fixture.OriginRepo = nil
 		return nil
 	})
@@ -1061,6 +1058,18 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^no commits exist now$`, func() error {
+		currentCommits := state.fixture.CommitTable(state.initialCommits.Cells[0])
+		noCommits := datatable.DataTable{}
+		noCommits.AddRow(state.initialCommits.Cells[0]...)
+		errDiff, errCount := currentCommits.EqualDataTable(noCommits)
+		if errCount == 0 {
+			return nil
+		}
+		fmt.Println(errDiff)
+		return errors.New("found unexpected commits")
+	})
+
 	suite.Step(`^no lineage exists now$`, func() error {
 		if state.fixture.DevRepo.Config.FullConfig.ContainsLineage() {
 			lineage := state.fixture.DevRepo.Config.FullConfig.Lineage
@@ -1113,7 +1122,6 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^origin deletes the "([^"]*)" branch$`, func(branch string) error {
-		state.initialRemoteBranches = slice.Remove(state.initialRemoteBranches, gitdomain.NewLocalBranchName(branch))
 		state.fixture.OriginRepo.RemoveBranch(gitdomain.NewLocalBranchName(branch))
 		return nil
 	})
@@ -1125,7 +1133,6 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 			return err
 		}
 		state.fixture.OriginRepo.RemoveBranch(gitdomain.NewLocalBranchName(branch))
-		state.initialRemoteBranches = slice.Remove(state.initialRemoteBranches, gitdomain.NewLocalBranchName(branch))
 		return nil
 	})
 
@@ -1133,7 +1140,6 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		for _, branchName := range []string{branch1, branch2} {
 			branch := gitdomain.NewLocalBranchName(branchName)
 			state.fixture.DevRepo.CreateBranch(branch, gitdomain.NewLocalBranchName("main"))
-			state.initialLocalBranches = append(state.initialLocalBranches, branch)
 		}
 		return nil
 	})
@@ -1150,7 +1156,8 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^the commits$`, func(table *messages.PickleStepArgument_PickleTable) error {
-		state.initialCommits = table
+		initialTable := datatable.FromGherkin(table)
+		state.initialCommits = &initialTable
 		// create the commits
 		commits := git.FromGherkinTable(table)
 		state.fixture.CreateCommits(commits)
@@ -1266,8 +1273,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	suite.Step(`^the current branch is "([^"]*)"$`, func(name string) error {
 		branch := gitdomain.NewLocalBranchName(name)
 		state.initialCurrentBranch = branch
-		if !slice.Contains(state.initialLocalBranches, branch) {
-			state.initialLocalBranches = append(state.initialLocalBranches, branch)
+		if !state.fixture.DevRepo.BranchExists(branch) {
 			state.fixture.DevRepo.CreateBranch(branch, gitdomain.NewLocalBranchName("main"))
 		}
 		state.fixture.DevRepo.CheckoutBranch(branch)
@@ -1277,26 +1283,23 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	suite.Step(`^the current branch is an? (local )?(feature|perennial|parked|contribution|observed) branch "([^"]*)"$`, func(localStr, branchType, branchName string) error {
 		branch := gitdomain.NewLocalBranchName(branchName)
 		isLocal := localStr != ""
-		switch branchType {
-		case "feature":
+		switch configdomain.NewBranchType(branchType) {
+		case configdomain.BranchTypeFeatureBranch:
 			state.fixture.DevRepo.CreateFeatureBranch(branch)
-			state.initialLineage.AddRow(branchName, "main")
-		case "perennial":
+		case configdomain.BranchTypePerennialBranch:
 			state.fixture.DevRepo.CreatePerennialBranches(branch)
-		case "parked":
+		case configdomain.BranchTypeParkedBranch:
 			state.fixture.DevRepo.CreateParkedBranches(branch)
-			state.initialLineage.AddRow(branchName, "main")
-		case "contribution":
+		case configdomain.BranchTypeContributionBranch:
 			state.fixture.DevRepo.CreateContributionBranches(branch)
-		case "observed":
+		case configdomain.BranchTypeObservedBranch:
 			state.fixture.DevRepo.CreateObservedBranches(branch)
+		case configdomain.BranchTypeMainBranch:
 		default:
 			panic(fmt.Sprintf("unknown branch type: %q", branchType))
 		}
-		state.initialLocalBranches = append(state.initialLocalBranches, branch)
 		if !isLocal {
-			state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
-			state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
+			state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
 		}
 		state.initialCurrentBranch = branch
 		// NOTE: reading the cached value here to keep the test suite fast by avoiding unnecessary disk access
@@ -1315,6 +1318,49 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^(contribution|feature|observed|parked) branch "([^"]*)" with these commits$`, func(branchTypeName, name string, table *messages.PickleStepArgument_PickleTable) error {
+		branchName := gitdomain.NewLocalBranchName(name)
+		switch configdomain.NewBranchType(branchTypeName) {
+		case configdomain.BranchTypeContributionBranch:
+			state.fixture.DevRepo.CreateContributionBranches(branchName)
+		case configdomain.BranchTypeFeatureBranch:
+			state.fixture.DevRepo.CreateFeatureBranch(branchName)
+		case configdomain.BranchTypeObservedBranch:
+			state.fixture.DevRepo.CreateObservedBranches(branchName)
+		case configdomain.BranchTypeParkedBranch:
+			state.fixture.DevRepo.CreateParkedBranches(branchName)
+		case configdomain.BranchTypeMainBranch, configdomain.BranchTypePerennialBranch:
+		}
+		state.fixture.DevRepo.CheckoutBranch(branchName)
+		state.fixture.DevRepo.PushBranchToRemote(branchName, gitdomain.RemoteOrigin)
+		for _, commit := range git.FromGherkinTable(table) {
+			state.fixture.DevRepo.CreateFile(commit.FileName, commit.FileContent)
+			state.fixture.DevRepo.StageFiles(commit.FileName)
+			state.fixture.DevRepo.CommitStagedChanges(commit.Message)
+			if commit.Locations.Contains(git.Location(gitdomain.RemoteOrigin)) {
+				state.fixture.DevRepo.PushBranch()
+			}
+		}
+		return nil
+	})
+
+	suite.Step(`^feature branch "([^"]*)" as a child of "([^"]*)" has these commits$`, func(name, parent string, table *messages.PickleStepArgument_PickleTable) error {
+		branch := gitdomain.NewLocalBranchName(name)
+		parentBranch := gitdomain.NewLocalBranchName(parent)
+		state.fixture.DevRepo.CreateChildFeatureBranch(branch, parentBranch)
+		state.fixture.DevRepo.CheckoutBranch(branch)
+		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
+		for _, commit := range git.FromGherkinTable(table) {
+			state.fixture.DevRepo.CreateFile(commit.FileName, commit.FileContent)
+			state.fixture.DevRepo.StageFiles(commit.FileName)
+			state.fixture.DevRepo.CommitStagedChanges(commit.Message)
+			if commit.Locations.Contains(git.Location(gitdomain.RemoteOrigin)) {
+				state.fixture.DevRepo.PushBranch()
+			}
+		}
+		return nil
+	})
+
 	suite.Step(`^the current branch is (?:now|still) "([^"]*)"$`, func(expected string) error {
 		state.fixture.DevRepo.CurrentBranchCache.Invalidate()
 		actual, err := state.fixture.DevRepo.CurrentBranch()
@@ -1341,8 +1387,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 
 	suite.Step(`^the initial lineage exists$`, func() error {
 		have := state.fixture.DevRepo.LineageTable()
-		state.initialLineage.Sort()
-		diff, errCnt := have.EqualDataTable(state.initialLineage)
+		diff, errCnt := have.EqualDataTable(*state.initialLineage)
 		if errCnt > 0 {
 			fmt.Printf("\nERROR! Found %d differences in the lineage\n\n", errCnt)
 			fmt.Printf("INITIAL LINEAGE:\n%s\n", state.initialLineage.String())
@@ -1355,18 +1400,19 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 
 	suite.Step(`^the initial branches and lineage exist$`, func() error {
 		// verify initial branches
-		have := state.fixture.Branches()
-		want := state.InitialBranches()
-		diff, errorCount := have.EqualDataTable(want)
+		currentBranches := state.fixture.Branches()
+		initialBranches := state.initialBranches
+		// fmt.Printf("\nINITIAL:\n%s\n", initialBranches)
+		// fmt.Printf("NOW:\n%s\n", currentBranches.String())
+		diff, errorCount := currentBranches.EqualDataTable(*initialBranches)
 		if errorCount != 0 {
 			fmt.Printf("\nERROR! Found %d differences in the existing branches\n\n", errorCount)
 			fmt.Println(diff)
 			return errors.New("mismatching branches found, see diff above")
 		}
 		// verify initial lineage
-		state.initialLineage.Sort()
-		have = state.fixture.DevRepo.LineageTable()
-		diff, errCnt := have.EqualDataTable(state.initialLineage)
+		currentLineage := state.fixture.DevRepo.LineageTable()
+		diff, errCnt := currentLineage.EqualDataTable(*state.initialLineage)
 		if errCnt > 0 {
 			fmt.Printf("\nERROR! Found %d differences in the lineage\n\n", errCnt)
 			fmt.Println(diff)
@@ -1377,10 +1423,10 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 
 	suite.Step(`^the initial branches exist$`, func() error {
 		have := state.fixture.Branches()
-		want := state.InitialBranches()
+		want := state.initialBranches
 		// fmt.Printf("HAVE:\n%s\n", have.String())
 		// fmt.Printf("WANT:\n%s\n", want.String())
-		diff, errorCount := have.EqualDataTable(want)
+		diff, errorCount := have.EqualDataTable(*want)
 		if errorCount != 0 {
 			fmt.Printf("\nERROR! Found %d differences in the existing branches\n\n", errorCount)
 			fmt.Println(diff)
@@ -1390,14 +1436,18 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^the initial commits exist$`, func() error {
-		return state.compareTable(state.initialCommits)
+		currentCommits := state.fixture.CommitTable(state.initialCommits.Cells[0])
+		errDiff, errCount := state.initialCommits.EqualDataTable(currentCommits)
+		if errCount == 0 {
+			return nil
+		}
+		fmt.Println(errDiff)
+		return errors.New("current commits are not the same as the initial commits")
 	})
 
 	suite.Step(`^the local feature branch "([^"]+)"$`, func(branch string) error {
 		branchName := gitdomain.NewLocalBranchName(branch)
 		state.fixture.DevRepo.CreateFeatureBranch(branchName)
-		state.initialLocalBranches = append(state.initialLocalBranches, branchName)
-		state.initialLineage.AddRow(branch, "main")
 		return nil
 	})
 
@@ -1406,11 +1456,8 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		for _, branchText := range []string{branch1, branch2} {
 			branch := gitdomain.NewLocalBranchName(branchText)
 			state.fixture.DevRepo.CreateFeatureBranch(branch)
-			state.initialLocalBranches = append(state.initialLocalBranches, branch)
-			state.initialLineage.AddRow(branchText, "main")
 			if !isLocal {
-				state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
-				state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
+				state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
 			}
 		}
 		return nil
@@ -1421,11 +1468,8 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		for _, branchText := range []string{branch1, branch2, branch3} {
 			branch := gitdomain.NewLocalBranchName(branchText)
 			state.fixture.DevRepo.CreateFeatureBranch(branch)
-			state.initialLocalBranches = append(state.initialLocalBranches, branch)
-			state.initialLineage.AddRow(branchText, "main")
 			if !isLocal {
-				state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
-				state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
+				state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
 			}
 		}
 		return nil
@@ -1434,7 +1478,6 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	suite.Step(`^the local observed branch "([^"]+)"$`, func(name string) error {
 		branch := gitdomain.NewLocalBranchName(name)
 		state.fixture.DevRepo.CreateObservedBranches(branch)
-		state.initialLocalBranches = append(state.initialLocalBranches, branch)
 		return nil
 	})
 
@@ -1443,11 +1486,9 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		branch2 := gitdomain.NewLocalBranchName(branch2Text)
 		isLocal := localStr != ""
 		state.fixture.DevRepo.CreatePerennialBranches(branch1, branch2)
-		state.initialLocalBranches = append(state.initialLocalBranches, branch1, branch2)
 		if !isLocal {
-			state.initialRemoteBranches = append(state.initialRemoteBranches, branch1, branch2)
-			state.fixture.DevRepo.PushBranchToRemote(branch1, gitdomain.OriginRemote)
-			state.fixture.DevRepo.PushBranchToRemote(branch2, gitdomain.OriginRemote)
+			state.fixture.DevRepo.PushBranchToRemote(branch1, gitdomain.RemoteOrigin)
+			state.fixture.DevRepo.PushBranchToRemote(branch2, gitdomain.RemoteOrigin)
 		}
 		return nil
 	})
@@ -1457,10 +1498,8 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		for _, branchText := range []string{branch1, branch2, branch3} {
 			branch := gitdomain.NewLocalBranchName(branchText)
 			state.fixture.DevRepo.CreatePerennialBranches(branch)
-			state.initialLocalBranches = append(state.initialLocalBranches, branch)
 			if !isLocal {
-				state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
-				state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
+				state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
 			}
 		}
 		return nil
@@ -1489,9 +1528,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	suite.Step(`^an observed branch "([^"]+)"$`, func(name string) error {
 		branch := gitdomain.NewLocalBranchName(name)
 		state.fixture.DevRepo.CreateBranch(branch, "main")
-		state.initialLocalBranches = append(state.initialLocalBranches, branch)
-		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
-		state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
+		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
 		return state.fixture.DevRepo.Config.SetObservedBranches(gitdomain.NewLocalBranchNames(name))
 	})
 
@@ -1594,7 +1631,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^these commits exist now$`, func(table *messages.PickleStepArgument_PickleTable) error {
-		return state.compareTable(table)
+		return state.compareGherkinTable(table)
 	})
 
 	suite.Step(`^these tags exist$`, func(table *messages.PickleStepArgument_PickleTable) error {
@@ -1641,7 +1678,19 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
-	suite.Step(`^this branch lineage exists now$`, func(input *messages.PickleStepArgument_PickleTable) error {
+	suite.Step(`^these branches exist now$`, func(input *messages.PickleStepArgument_PickleTable) error {
+		currentBranches := state.fixture.Branches()
+		// fmt.Printf("NOW:\n%s\n", currentBranches.String())
+		diff, errorCount := currentBranches.EqualGherkin(input)
+		if errorCount != 0 {
+			fmt.Printf("\nERROR! Found %d differences in the existing branches\n\n", errorCount)
+			fmt.Println(diff)
+			return errors.New("mismatching branches found, see diff above")
+		}
+		return nil
+	})
+
+	suite.Step(`^this lineage exists now$`, func(input *messages.PickleStepArgument_PickleTable) error {
 		table := state.fixture.DevRepo.LineageTable()
 		diff, errCount := table.EqualGherkin(input)
 		if errCount > 0 {
