@@ -6,18 +6,17 @@ import (
 	"path/filepath"
 
 	"github.com/cucumber/messages-go/v10"
-	"github.com/git-town/git-town/v13/src/git"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/src/gohacks/cache"
-	"github.com/git-town/git-town/v13/src/gohacks/slice"
-	"github.com/git-town/git-town/v13/test/asserts"
-	"github.com/git-town/git-town/v13/test/commands"
-	"github.com/git-town/git-town/v13/test/datatable"
-	"github.com/git-town/git-town/v13/test/filesystem"
-	testgit "github.com/git-town/git-town/v13/test/git"
-	"github.com/git-town/git-town/v13/test/helpers"
-	"github.com/git-town/git-town/v13/test/subshell"
-	"github.com/git-town/git-town/v13/test/testruntime"
+	"github.com/git-town/git-town/v14/src/git"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/gohacks/cache"
+	"github.com/git-town/git-town/v14/test/asserts"
+	"github.com/git-town/git-town/v14/test/commands"
+	"github.com/git-town/git-town/v14/test/datatable"
+	"github.com/git-town/git-town/v14/test/filesystem"
+	testgit "github.com/git-town/git-town/v14/test/git"
+	"github.com/git-town/git-town/v14/test/helpers"
+	"github.com/git-town/git-town/v14/test/subshell"
+	"github.com/git-town/git-town/v14/test/testruntime"
 )
 
 // Fixture is a complete Git environment for a Cucumber scenario.
@@ -54,7 +53,7 @@ type Fixture struct {
 func CloneFixture(original Fixture, dir string) Fixture {
 	filesystem.CopyDirectory(original.Dir, dir)
 	binDir := filepath.Join(dir, "bin")
-	originDir := filepath.Join(dir, gitdomain.OriginRemote.String())
+	originDir := filepath.Join(dir, gitdomain.RemoteOrigin.String())
 	originRepo := testruntime.New(originDir, dir, "")
 	developerDir := filepath.Join(dir, "developer")
 	devRepo := testruntime.New(developerDir, dir, binDir)
@@ -65,8 +64,8 @@ func CloneFixture(original Fixture, dir string) Fixture {
 	}
 	// Since we copied the files from the memoized directory,
 	// we have to set the "origin" remote to the copied origin repo here.
-	result.DevRepo.MustRun("git", "remote", "remove", gitdomain.OriginRemote.String())
-	result.DevRepo.AddRemote(gitdomain.OriginRemote, result.originRepoPath())
+	result.DevRepo.MustRun("git", "remote", "remove", gitdomain.RemoteOrigin.String())
+	result.DevRepo.AddRemote(gitdomain.RemoteOrigin, result.originRepoPath())
 	result.DevRepo.Fetch()
 	// and connect the main branches again
 	result.DevRepo.ConnectTrackingBranch(gitdomain.NewLocalBranchName("main"))
@@ -156,30 +155,27 @@ func (self *Fixture) AddSubmoduleRepo() {
 
 // AddUpstream adds an upstream repository.
 func (self *Fixture) AddUpstream() {
-	repo := testruntime.Clone(self.DevRepo.TestRunner, filepath.Join(self.Dir, gitdomain.UpstreamRemote.String()))
+	repo := testruntime.Clone(self.DevRepo.TestRunner, filepath.Join(self.Dir, gitdomain.RemoteUpstream.String()))
 	self.UpstreamRepo = &repo
-	self.DevRepo.AddRemote(gitdomain.UpstreamRemote, self.UpstreamRepo.WorkingDir)
+	self.DevRepo.AddRemote(gitdomain.RemoteUpstream, self.UpstreamRepo.WorkingDir)
 }
 
 // Branches provides a tabular list of all branches in this Fixture.
 func (self *Fixture) Branches() datatable.DataTable {
 	result := datatable.DataTable{}
 	result.AddRow("REPOSITORY", "BRANCHES")
-	mainBranch := self.DevRepo.Config.FullConfig.MainBranch
-	localBranches, err := self.DevRepo.LocalBranchesMainFirst(mainBranch)
-	asserts.NoError(err)
-	localBranches = localBranches.RemoveWorkspaceMarkers().Hoist(self.DevRepo.Config.FullConfig.MainBranch)
+	mainBranch := gitdomain.NewLocalBranchName("main")
 	initialBranch := gitdomain.NewLocalBranchName("initial")
-	localBranches = slice.Remove(localBranches, initialBranch)
-	localBranchesJoined := localBranches.Join(", ")
+	localBranches, err := self.DevRepo.LocalBranches()
+	asserts.NoError(err)
+	localBranchesJoined := localBranches.RemoveWorktreeMarkers().Remove(initialBranch).Hoist(mainBranch).Join(", ")
 	if self.OriginRepo == nil {
 		result.AddRow("local", localBranchesJoined)
 		return result
 	}
-	originBranches, err := self.OriginRepo.LocalBranchesMainFirst(mainBranch)
+	originBranches, err := self.OriginRepo.LocalBranches()
 	asserts.NoError(err)
-	originBranches = slice.Remove(originBranches, initialBranch)
-	originBranchesJoined := originBranches.Join(", ")
+	originBranchesJoined := originBranches.Remove(initialBranch).Hoist(mainBranch).Join(", ")
 	if localBranchesJoined == originBranchesJoined {
 		result.AddRow("local, origin", localBranchesJoined)
 	} else {
@@ -200,7 +196,7 @@ func (self Fixture) CommitTable(fields []string) datatable.DataTable {
 	}
 	if self.OriginRepo != nil {
 		originCommits := self.OriginRepo.Commits(fields, gitdomain.NewLocalBranchName("main"))
-		builder.AddMany(originCommits, gitdomain.OriginRemote.String())
+		builder.AddMany(originCommits, gitdomain.RemoteOrigin.String())
 	}
 	if self.UpstreamRepo != nil {
 		upstreamCommits := self.UpstreamRepo.Commits(fields, gitdomain.NewLocalBranchName("main"))
@@ -216,22 +212,20 @@ func (self Fixture) CommitTable(fields []string) datatable.DataTable {
 // CreateCommits creates the commits described by the given Gherkin table in this Git repository.
 func (self *Fixture) CreateCommits(commits []testgit.Commit) {
 	for _, commit := range commits {
-		for _, location := range commit.Locations {
-			switch location {
-			case "coworker":
-				self.CoworkerRepo.CreateCommit(commit)
-			case "local":
-				self.DevRepo.CreateCommit(commit)
-			case "local, origin":
-				self.DevRepo.CreateCommit(commit)
-				self.DevRepo.PushBranch()
-			case "origin":
-				self.OriginRepo.CreateCommit(commit)
-			case "upstream":
-				self.UpstreamRepo.CreateCommit(commit)
-			default:
-				log.Fatalf("unknown commit location %q", commit.Locations)
-			}
+		switch {
+		case commit.Locations.Matches(testgit.LocationCoworker):
+			self.CoworkerRepo.CreateCommit(commit)
+		case commit.Locations.Matches(testgit.LocationLocal):
+			self.DevRepo.CreateCommit(commit)
+		case commit.Locations.Matches(testgit.LocationLocal, testgit.LocationOrigin):
+			self.DevRepo.CreateCommit(commit)
+			self.DevRepo.PushBranch()
+		case commit.Locations.Matches(testgit.LocationOrigin):
+			self.OriginRepo.CreateCommit(commit)
+		case commit.Locations.Matches(testgit.LocationUpstream):
+			self.UpstreamRepo.CreateCommit(commit)
+		default:
+			log.Fatalf("unknown commit locations %q", commit.Locations)
 		}
 	}
 	// after setting up the commits, check out the "initial" branch in the origin repo so that we can git-push to it.
@@ -267,7 +261,7 @@ func (self Fixture) TagTable() datatable.DataTable {
 	builder.AddMany(localTags, "local")
 	if self.OriginRepo != nil {
 		originTags := self.OriginRepo.Tags()
-		builder.AddMany(originTags, gitdomain.OriginRemote.String())
+		builder.AddMany(originTags, gitdomain.RemoteOrigin.String())
 	}
 	return builder.Table()
 }
@@ -300,7 +294,7 @@ func (self Fixture) initializeWorkspace(repo *testruntime.TestRuntime) {
 
 // originRepoPath provides the full path to the Git repository with the given name.
 func (self Fixture) originRepoPath() string {
-	return filepath.Join(self.Dir, gitdomain.OriginRemote.String())
+	return filepath.Join(self.Dir, gitdomain.RemoteOrigin.String())
 }
 
 // submoduleRepoPath provides the full path to the Git repository with the given name.
