@@ -5,10 +5,10 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/test/asserts"
-	"github.com/git-town/git-town/v13/test/fixture"
-	"github.com/git-town/git-town/v13/test/git"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/test/asserts"
+	"github.com/git-town/git-town/v14/test/fixture"
+	"github.com/git-town/git-town/v14/test/git"
 	"github.com/shoenig/test/must"
 )
 
@@ -24,7 +24,7 @@ func TestFixture(t *testing.T) {
 		asserts.IsGitRepo(t, filepath.Join(dir, "cloned", "developer"))
 		asserts.BranchExists(t, filepath.Join(dir, "cloned", "developer"), "main")
 		// check pushing
-		cloned.DevRepo.PushBranchToRemote(gitdomain.NewLocalBranchName("main"), gitdomain.OriginRemote)
+		cloned.DevRepo.PushBranchToRemote(gitdomain.NewLocalBranchName("main"), gitdomain.RemoteOrigin)
 	})
 
 	t.Run("NewStandardFixture", func(t *testing.T) {
@@ -87,47 +87,48 @@ func TestFixture(t *testing.T) {
 		memoizedGitEnv := fixture.NewStandardFixture(filepath.Join(dir, "memoized"))
 		cloned := fixture.CloneFixture(memoizedGitEnv, filepath.Join(dir, "cloned"))
 		// create the commits
+		mainBranch := gitdomain.NewLocalBranchName("main")
 		cloned.CreateCommits([]git.Commit{
 			{
-				Branch:      gitdomain.NewLocalBranchName("main"),
-				FileContent: "lc",
+				Branch:      mainBranch,
+				FileContent: "local and origin content",
+				FileName:    "loc-rem-file",
+				Locations:   git.Locations{git.LocationLocal, git.LocationOrigin},
+				Message:     "local and origin commit",
+			},
+			{
+				Branch:      mainBranch,
+				FileContent: "local content",
 				FileName:    "local-file",
-				Locations:   []string{"local"},
+				Locations:   git.Locations{git.LocationLocal},
 				Message:     "local commit",
 			},
 			{
-				Branch:      gitdomain.NewLocalBranchName("main"),
-				FileContent: "rc",
+				Branch:      mainBranch,
+				FileContent: "origin content",
 				FileName:    "origin-file",
-				Locations:   []string{"origin"},
+				Locations:   git.Locations{git.LocationOrigin},
 				Message:     "origin commit",
 			},
-			{
-				Branch:      gitdomain.NewLocalBranchName("main"),
-				FileContent: "lrc",
-				FileName:    "loc-rem-file",
-				Locations:   []string{"local", "origin"},
-				Message:     "local and origin commit",
-			},
 		})
 		// verify local commits
 		commits := cloned.DevRepo.Commits([]string{"FILE NAME", "FILE CONTENT"}, gitdomain.NewLocalBranchName("main"))
 		must.Len(t, 2, commits)
-		must.EqOp(t, "local commit", commits[0].Message)
-		must.EqOp(t, "local-file", commits[0].FileName)
-		must.EqOp(t, "lc", commits[0].FileContent)
-		must.EqOp(t, "local and origin commit", commits[1].Message)
-		must.EqOp(t, "loc-rem-file", commits[1].FileName)
-		must.EqOp(t, "lrc", commits[1].FileContent)
+		must.EqOp(t, "local and origin commit", commits[0].Message)
+		must.EqOp(t, "loc-rem-file", commits[0].FileName)
+		must.EqOp(t, "local and origin content", commits[0].FileContent)
+		must.EqOp(t, "local commit", commits[1].Message)
+		must.EqOp(t, "local-file", commits[1].FileName)
+		must.EqOp(t, "local content", commits[1].FileContent)
 		// verify origin commits
 		commits = cloned.OriginRepo.Commits([]string{"FILE NAME", "FILE CONTENT"}, gitdomain.NewLocalBranchName("main"))
 		must.Len(t, 2, commits)
-		must.EqOp(t, "origin commit", commits[0].Message)
-		must.EqOp(t, "origin-file", commits[0].FileName)
-		must.EqOp(t, "rc", commits[0].FileContent)
-		must.EqOp(t, "local and origin commit", commits[1].Message)
-		must.EqOp(t, "loc-rem-file", commits[1].FileName)
-		must.EqOp(t, "lrc", commits[1].FileContent)
+		must.EqOp(t, "local and origin commit", commits[0].Message)
+		must.EqOp(t, "loc-rem-file", commits[0].FileName)
+		must.EqOp(t, "local and origin content", commits[0].FileContent)
+		must.EqOp(t, "origin commit", commits[1].Message)
+		must.EqOp(t, "origin-file", commits[1].FileName)
+		must.EqOp(t, "origin content", commits[1].FileContent)
 		// verify origin is at "initial" branch
 		branch, err := cloned.OriginRepo.CurrentBranch()
 		must.NoError(t, err)
@@ -166,7 +167,7 @@ func TestFixture(t *testing.T) {
 				FileName:    "local-origin.md",
 				Message:     "local-origin",
 			})
-			cloned.DevRepo.PushBranchToRemote(gitdomain.NewLocalBranchName("main"), gitdomain.OriginRemote)
+			cloned.DevRepo.PushBranchToRemote(gitdomain.NewLocalBranchName("main"), gitdomain.RemoteOrigin)
 			cloned.OriginRepo.CreateCommit(git.Commit{
 				Branch:      gitdomain.NewLocalBranchName("main"),
 				FileContent: "two",
