@@ -2,8 +2,8 @@ package git
 
 import (
 	"github.com/cucumber/messages-go/v10"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/test/helpers"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/test/helpers"
 )
 
 // DefaultCommit provides a new Commit instance populated with the default values used in the absence of value specified by the test.
@@ -12,7 +12,7 @@ func DefaultCommit(filenameSuffix string) Commit {
 		Branch:      gitdomain.NewLocalBranchName("main"),
 		FileContent: "default file content",
 		FileName:    "default_file_name_" + filenameSuffix,
-		Locations:   []string{"local", gitdomain.OriginRemote.String()},
+		Locations:   Locations{LocationLocal, LocationOrigin},
 		Message:     "default commit message",
 	}
 }
